@@ -103,13 +103,13 @@ bool BasicIndexingQueue::process(FileMapping& file, UpdateDirFlags flags)
 
     bool forced = flags & ForceUpdate;
     bool recursive = flags & UpdateRecursive;
-    bool indexingRequired = shouldIndex(file, mimetype);
+    bool indexingRequired = (flags & ExtendedAttributesOnly) || shouldIndex(file, mimetype);
 
     QFileInfo info(file.url());
     if (info.isDir()) {
         if (forced || indexingRequired) {
             startedIndexing = true;
-            index(file, mimetype);
+            index(file, mimetype, flags);
         }
 
         // We don't want to follow system links
@@ -123,7 +123,7 @@ bool BasicIndexingQueue::process(FileMapping& file, UpdateDirFlags flags)
         }
     } else if (info.isFile() && (forced || indexingRequired)) {
         startedIndexing = true;
-        index(file, mimetype);
+        index(file, mimetype, flags);
     }
 
     return startedIndexing;
@@ -148,7 +148,7 @@ bool BasicIndexingQueue::shouldIndex(FileMapping& file, const QString& mimetype)
     }
 
     XapianDocument doc = m_db->xapianDatabase()->document(file.id());
-    QString dtStr = doc.fetchTermStartsWith("DT_M");
+    const QString dtStr = doc.fetchTermStartsWith("DT_M");
     if (dtStr.isEmpty()) {
         return true;
     }
@@ -174,13 +174,39 @@ bool BasicIndexingQueue::shouldIndexContents(const QString& dir)
     return m_config->shouldFolderBeIndexed(dir);
 }
 
-void BasicIndexingQueue::index(const FileMapping& file, const QString& mimetype)
+void BasicIndexingQueue::index(FileMapping& file, const QString& mimetype,
+                               UpdateDirFlags flags)
 {
     qDebug() << file.id() << file.url();
 
-    BasicIndexingJob job(&m_db->sqlDatabase(), file, mimetype);
-    if (job.index()) {
-        Q_EMIT newDocument(job.id(), job.document());
+    bool xattrOnly = (flags & Baloo::ExtendedAttributesOnly);
+
+    if (!xattrOnly) {
+        if (file.id() == 0) {
+            if (!file.create(m_db->sqlDatabase())) {
+                qWarning() << "Cannot create fileMapping for" << file.url();
+            }
+            else {
+                BasicIndexingJob job(file, mimetype, m_config->onlyBasicIndexing());
+                if (job.index()) {
+                    Q_EMIT newDocument(job.id(), job.document());
+                }
+            }
+        }
+    }
+    else {
+        XapianDocument doc = m_db->xapianDatabase()->document(file.id());
+
+        bool modified = false;
+        modified |= doc.removeTermStartsWith("R");
+        modified |= doc.removeTermStartsWith("TA");
+        modified |= doc.removeTermStartsWith("TAG");
+        modified |= doc.removeTermStartsWith("C");
+
+        modified |= BasicIndexingJob::indexXAttr(file.url(), doc);
+        if (modified) {
+            Q_EMIT newDocument(file.id(), doc.doc());
+        }
     }
 
     QTimer::singleShot(0, this, SLOT(finishIteration()));
