@@ -25,7 +25,7 @@
 #include <QTime>
 #include <QCoreApplication>
 
-#include "fileindexer.h"
+#include "fileextractor.h"
 
 #include "../basicindexingqueue.h"
 #include "../commitqueue.h"
@@ -73,7 +73,7 @@ int main(int argc, char** argv)
         if (!fileMap.fetch(db.sqlDatabase()))
             continue;
 
-        Baloo::FileIndexer* job = new Baloo::FileIndexer(fileMap.id(), fileMap.url());
+        auto job = new Baloo::FileExtractor(fileMap.id(), fileMap.url());
         job->setCustomPath(db.path());
         job->exec();
 
